@@ -55,7 +55,7 @@ utils::globalVariables(c(
 #' `spreadProbs <- lowSpreadProb + (angleQuality * diff(spreadProbsLH))`
 #' To maintain an expected `spreadProb` that is the same as the asymmetric
 #' `spreadProbs`, these are then rescaled so that the mean of the
-#' asymmetric spreadProbs is always equal to spreadProb at every iteration:
+#' asymmetric `spreadProbs` is always equal to spreadProb at every iteration:
 #' `spreadProbs <- spreadProbs - diff(c(spreadProb, mean(spreadProbs)))`
 #'
 #' @section Breaking out of spread events:
@@ -375,7 +375,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
     spreadStateExists <- is(spreadState, "data.table")
     spreadProbLaterExists <- TRUE
 
-    if (!is(spreadProbLater, "Raster")) {
+    if (!isGridded(spreadProbLater)) {
       if (anyNA(spreadProbLater)) {
         spreadProbLaterExists <- FALSE
         spreadProbLater <- spreadProb
@@ -479,19 +479,21 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
       needEmptySpreads <- TRUE
       stNamespace <- asNamespace("SpaDES.tools")
       if (exists("spreadsDTInNamespace", envir = stNamespace)) {
-        spreadsDT <- getFromNamespace("spreadsDTInNamespace", "SpaDES.tools")
+        cellsState <- integer()
+        # spreadsDT <- getFromNamespace("spreadsDTInNamespace", "SpaDES.tools")
         # set(spreadsDT, NULL, "spreads", 0L)
-        # spreads <- spreadsDT$spreads
-        if (identical(NROW(spreadsDT), ncells)) {
+        # spreads <- cellsState
+        if (identical(NROW(cellsState), ncells)) {
           needEmptySpreads <- FALSE
         }
       }
       if (needEmptySpreads) {
-        spreadsDT <- data.table(spreads = vector("integer", ncells))
-        set(spreadsDT, NULL, "spreads", 0L)
+        cellsState <- rep(0L, ncells) # vector("integer", ncells)
+        # spreadsDT <- data.table(spreads = vector("integer", ncells))
+        # set(spreadsDT, NULL, "spreads", 0L)
         # put the empty data.table into the SpaDES.tools namespace
-        assignInMyNamespace("spreadsDTInNamespace", spreadsDT)
-        on.exit(assignInMyNamespace("spreadsDTInNamespace", integer()), add = TRUE)
+        # assignInMyNamespace("spreadsDTInNamespace", spreadsDT)
+        # on.exit(assignInMyNamespace("spreadsDTInNamespace", integer()), add = TRUE)
       }
     }
 
@@ -553,12 +555,13 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
     if (!allowOverlap && !returnDistances) {
       if (id || returnIndices > 0 || relativeSpreadProb) {
         if (!spreadStateExists) {
-          set(spreadsDT, loci, "spreads", seq_along(loci))
+          cellsState[loci] <- seq_along(loci)
+          # set(spreadsDT, loci, "spreads", seq_along(loci))
           ##DT spreads[loci] <- seq_along(loci)
           # give values to spreads vector at initialLoci
         }
       } else {
-        spreadsDT$spreads[loci] <- n
+        cellsState[loci] <- n
       }
       spreadsIndices <- unname(loci)
       #browser(expr = exists("aaaaa"))
@@ -568,7 +571,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
     }
 
     # Convert mask and NAs to 0 on the spreadProb Raster
-    if (is(spreadProb, "Raster")) {
+    if (isGridded(spreadProb)) {
       # convert NA to 0s
       #isNASpreadProb <- is.na(spreadProb[])
       # if (anyNA(spreadProb[])) {
@@ -583,7 +586,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
     }
 
     # Convert mask and NAs to 0 on the spreadProbLater Raster
-    if (is(spreadProbLater, "Raster")) {
+    if (isGridded(spreadProbLater)) {
     } else if (is.numeric(spreadProbLater)) {
       # Translate numeric spreadProbLater into a Raster, if there is a mask
       if (is(mask, "Raster")) {
@@ -593,7 +596,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
     }
 
     # Mask spreadProbLater and spreadProb
-    if (is(mask, "Raster")) {
+    if (isGridded(mask)) {
       spreadProbLater[mask[] == 1L] <- 0L
       spreadProb[mask[] == 1L] <- 0L
     }
@@ -715,7 +718,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
         }
       } else {
         # Keep only the ones where it hasn't been spread to yet
-        keep <- spreadsDT$spreads[potentials[, 2L]] == 0L
+        keep <- cellsState[potentials[, 2L]] == 0L
         # keep <- spreads[potentials[, 2L]] == 0L
         potentials <- potentials[keep, , drop = FALSE]
       }
@@ -761,7 +764,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
             a <- cbind(id = spreads[potentials[, 1L]], to = potentials[, 2L],
                        xyFromCell(landscape, potentials[, 2L]))
           } else {
-            a <- cbind(id = spreadsDT$spreads[potentials[, 1L]], to = potentials[, 2L],
+            a <- cbind(id = cellsState[potentials[, 1L]], to = potentials[, 2L],
                        xyFromCell(landscape, potentials[, 2L]))
           }
         }
@@ -834,7 +837,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
                 a <- cbind(potentials, id = spreads[potentials[, "from"]],
                            xyFromCell(landscape, potentials[, "to"]))
               } else {
-                a <- cbind(potentials, id = spreadsDT$spreads[potentials[, "from"]],
+                a <- cbind(potentials, id = cellsState[potentials[, "from"]],
                            xyFromCell(landscape, potentials[, "to"]))
               }
             }
@@ -868,7 +871,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
           } else {
             # actually interested in potential[,2L], but they don't have values yet..
             #  can use their source
-            len <- tabulate(spreadsDT$spreads[potentials[, 1L]], length(maxSize))
+            len <- tabulate(cellsState[potentials[, 1L]], length(maxSize))
           }
           if (any((size + len) > maxSize & size <= maxSize)) {
             whichID <- which(size + len > maxSize)
@@ -880,7 +883,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
               if (useMatrixVersionSpreads) {
                 thisID <- which(potentials[, 3L] == whichID[i])
               } else {
-                thisID <- which(spreadsDT$spreads[potentials[, 1L]] == whichID[i])
+                thisID <- which(cellsState[potentials[, 1L]] == whichID[i])
               }
 
               # some unusual cases where there are none on the spreads. Unsure how this occurs
@@ -913,10 +916,10 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
                                   landscape = if (landRasNeeded) landRas[potentials[, 2L]] else NULL,
                                   cells = potentials[, 2L], prev = 0)
             } else {
-              prevCells <- cbind(id = spreadsDT$spreads[whgtZero],
+              prevCells <- cbind(id = cellsState[whgtZero],
                                  landscape = if (landRasNeeded) landRas[whgtZero] else NULL,
                                  cells = whgtZero, prev = 1)
-              eventCells <- cbind(id = spreadsDT$spreads[potentials[, 1L]],
+              eventCells <- cbind(id = cellsState[potentials[, 1L]],
                                   landscape = if (landRasNeeded) landRas[potentials[, 2L]] else NULL,
                                   cells = potentials[, 2L], prev = 0)
             }
@@ -1023,9 +1026,11 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
           } else {
             if (id || returnIndices > 0 || relativeSpreadProb) {
               # give new cells, the id of the source cell
-              set(spreadsDT, events, "spreads", spreadsDT$spreads[potentials[, 1L]])
+              cellsState[events] <- cellsState[potentials[, 1L]]
+              # set(spreadsDT, events, "spreads", cellsState[potentials[, 1L]])
             } else {
-              set(spreadsDT, events, "spreads", n)
+              cellsState[events] <- n
+              # set(spreadsDT, events, "spreads", n)
             }
             curEventsLen <- length(events)
             addedIndices <- prevSpreadIndicesActiveLen + 1:curEventsLen
@@ -1053,7 +1058,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
                 if (useMatrixVersionSpreads) {
                   maxSizeKeep <- !spreads[events] %in% whichID
                 } else {
-                  maxSizeKeep <- !spreadsDT$spreads[events] %in% whichID
+                  maxSizeKeep <- !cellsState[events] %in% whichID
                 }
               }
               events <- events[maxSizeKeep]
@@ -1093,8 +1098,8 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
               tooSmall <- tabulate(spreads, length(maxSize)) < maxSize
               inactive <- tabulate(spreads[events], length(maxSize)) == 0
             } else {
-              tooSmall <- tabulate(spreadsDT$spreads, length(maxSize)) < maxSize
-              inactive <- tabulate(spreadsDT$spreads[events], length(maxSize)) == 0
+              tooSmall <- tabulate(cellsState, length(maxSize)) < maxSize
+              inactive <- tabulate(cellsState[events], length(maxSize)) == 0
             }
           }
 
@@ -1159,7 +1164,7 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
         #   }
         # } else {
              plotCur <- terra::rast(landscape)
-             plotCur <- setValues(plotCur, spreadsDT$spreads)
+             plotCur <- setValues(plotCur, cellsState)
              terra::plot(plotCur)
         # }
       }
@@ -1203,10 +1208,10 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
         # wh already contains the potentials for next iteration -- these should be not duplicated
         #   inside "completed"
         wh <- wh[!(wh %in% potentials[, 2L])]
-        completed <- data.table(indices = wh, id = spreadsDT$spreads[wh], active = FALSE)
+        completed <- data.table(indices = wh, id = cellsState[wh], active = FALSE)
         if (NROW(potentials) > 0) {
           active <- data.table(indices = as.integer(potentials[, 2L]),
-                               id = spreadsDT$spreads[potentials[, 1L]],
+                               id = cellsState[potentials[, 1L]],
                                active = TRUE)
         } else {
           active <- data.table(indices = integer(0), id = integer(0), active = logical(0))
@@ -1250,7 +1255,8 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
         }
       if  (!(useMatrixVersionSpreads)) {
         #browser(expr = exists("aaaaa"))
-        set(spreadsDT, allCells$indices, "spreads", 0L)
+        cellsState[allCells$indices] <- 0L
+        # set(spreadsDT, allCells$indices, "spreads", 0L)
         # remove the previous on.exit which had the effect of deleting the contents
         #   completely on a failed `spread`. Here, we want to delete the previous
         #   on.exit --> allowing the object to stay intact, but with only zeros.
@@ -1289,14 +1295,16 @@ spread <- function(landscape, loci = NA_real_, spreadProb = 0.23, persistence =
         landscape[pixVal$indices] <- pixVal$V1
       }
     } else {
-      landscape[wh] <- spreadsDT$spreads[wh]
+      landscape[wh] <- cellsState[wh]
       if (exists("potentials")) {
         if (NROW(potentials) > 0) {
-          landscape[potentials[, 1L]] <- spreadsDT$spreads[potentials[, 2L]]
-          set(spreadsDT, as.integer(potentials[, 1L]), "spreads", 0L)
+          landscape[potentials[, 1L]] <- cellsState[potentials[, 2L]]
+          cellsState[as.integer(potentials[, 1L])] <- 0L
+          # set(spreadsDT, as.integer(potentials[, 1L]), "spreads", 0L)
         }
       }
-      set(spreadsDT, wh, "spreads", 0L)
+      cellsState[wh] <- 0L
+      # set(spreadsDT, wh, "spreads", 0L)
 
     }
     return(landscape)
